@@ -1,6 +1,7 @@
 package operator
 
 import (
+	"context"
 	"fmt"
 	"reflect"
 	"time"
@@ -8,33 +9,26 @@ import (
 	"k8s.io/apimachinery/pkg/api/errors"
 	kmeta "k8s.io/apimachinery/pkg/api/meta"
 	metaapi "k8s.io/apimachinery/pkg/apis/meta/v1"
+	utilruntime "k8s.io/apimachinery/pkg/util/runtime"
 	"k8s.io/apimachinery/pkg/util/wait"
 	kubeinformers "k8s.io/client-go/informers"
-	kubeset "k8s.io/client-go/kubernetes"
-	appsset "k8s.io/client-go/kubernetes/typed/apps/v1"
-	batchset "k8s.io/client-go/kubernetes/typed/batch/v1beta1"
-	coreset "k8s.io/client-go/kubernetes/typed/core/v1"
-	rbacset "k8s.io/client-go/kubernetes/typed/rbac/v1"
+	kubeclient "k8s.io/client-go/kubernetes"
 	restclient "k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/cache"
 	"k8s.io/client-go/util/workqueue"
 	"k8s.io/klog"
 
-	configapiv1 "github.com/openshift/api/config/v1"
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
-	operatorapi "github.com/openshift/api/operator/v1"
-	configset "github.com/openshift/client-go/config/clientset/versioned"
-	configsetv1 "github.com/openshift/client-go/config/clientset/versioned/typed/config/v1"
+	operatorv1 "github.com/openshift/api/operator/v1"
+	configclient "github.com/openshift/client-go/config/clientset/versioned"
 	configinformers "github.com/openshift/client-go/config/informers/externalversions"
-	regopset "github.com/openshift/client-go/imageregistry/clientset/versioned"
-	regopinformers "github.com/openshift/client-go/imageregistry/informers/externalversions"
-	routeset "github.com/openshift/client-go/route/clientset/versioned"
-	routesetv1 "github.com/openshift/client-go/route/clientset/versioned/typed/route/v1"
+	imageregistryclient "github.com/openshift/client-go/imageregistry/clientset/versioned"
+	imageregistryinformers "github.com/openshift/client-go/imageregistry/informers/externalversions"
+	routeclient "github.com/openshift/client-go/route/clientset/versioned"
 	routeinformers "github.com/openshift/client-go/route/informers/externalversions"
 
-	"github.com/openshift/cluster-image-registry-operator/defaults"
 	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
-	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
+	"github.com/openshift/cluster-image-registry-operator/pkg/defaults"
 	"github.com/openshift/cluster-image-registry-operator/pkg/resource"
 	"github.com/openshift/cluster-image-registry-operator/pkg/resource/object"
 	"github.com/openshift/cluster-image-registry-operator/pkg/resource/strategy"
@@ -42,10 +36,9 @@ import (
 )
 
 const (
-	openshiftConfigNamespace = "openshift-config"
-	kubeSystemNamespace      = "kube-system"
-	workqueueKey             = "changes"
-	defaultResyncDuration    = 10 * time.Minute
+	kubeSystemNamespace   = "kube-system"
+	workqueueKey          = "changes"
+	defaultResyncDuration = 10 * time.Minute
 )
 
 type permanentError struct {
@@ -64,45 +57,28 @@ func (e permanentError) Error() string {
 	return e.Err.Error()
 }
 
-func Parameters(namespace string) *parameters.Globals {
-	p := &parameters.Globals{}
-
-	p.Deployment.Namespace = namespace
-	p.Deployment.Labels = map[string]string{"docker-registry": "default"}
-
-	p.Pod.ServiceAccount = "registry"
-	p.Container.Port = 5000
-
-	p.Healthz.Route = "/healthz"
-	p.Healthz.TimeoutSeconds = 5
-
-	p.Service.Name = defaults.ImageRegistryName
-	p.ImageConfig.Name = "cluster"
-	p.CAConfig.Name = defaults.ImageRegistryCertificatesName
-	p.ServiceCA.Name = "serviceca"
-	p.TrustedCA.Name = "trusted-ca"
-
-	return p
-}
-
 // NewController returns a controller for openshift image registry objects.
 //
 // This controller keeps track of resources needed in order to have openshift
 // internal registry working.
-func NewController(kubeconfig *restclient.Config) (*Controller, error) {
-	namespace, err := regopclient.GetWatchNamespace()
-	if err != nil {
-		klog.Fatalf("failed to get watch namespace: %s", err)
-	}
-
-	p := Parameters(namespace)
-
+func NewController(
+	kubeconfig *restclient.Config,
+	kubeClient kubeclient.Interface,
+	configClient configclient.Interface,
+	imageregistryClient imageregistryclient.Interface,
+	routeClient routeclient.Interface,
+	kubeInformerFactory kubeinformers.SharedInformerFactory,
+	openshiftConfigKubeInformerFactory kubeinformers.SharedInformerFactory,
+	kubeSystemKubeInformerFactory kubeinformers.SharedInformerFactory,
+	configInformerFactory configinformers.SharedInformerFactory,
+	regopInformerFactory imageregistryinformers.SharedInformerFactory,
+	routeInformerFactory routeinformers.SharedInformerFactory,
+) *Controller {
 	listers := &regopclient.Listers{}
 	clients := &regopclient.Clients{}
 	c := &Controller{
 		kubeconfig: kubeconfig,
-		params:     *p,
-		generator:  resource.NewGenerator(kubeconfig, clients, listers, p),
+		generator:  resource.NewGenerator(kubeconfig, clients, listers),
 		workqueue:  workqueue.NewNamedRateLimitingQueue(workqueue.DefaultControllerRateLimiter(), "Changes"),
 		listers:    listers,
 		clients:    clients,
@@ -111,17 +87,98 @@ func NewController(kubeconfig *restclient.Config) (*Controller, error) {
 	// Initial event to bootstrap CR if it doesn't exist.
 	c.workqueue.AddRateLimited(workqueueKey)
 
-	return c, nil
+	c.clients.Core = kubeClient.CoreV1()
+	c.clients.Apps = kubeClient.AppsV1()
+	c.clients.RBAC = kubeClient.RbacV1()
+	c.clients.Kube = kubeClient
+	c.clients.Route = routeClient.RouteV1()
+	c.clients.Config = configClient.ConfigV1()
+	c.clients.RegOp = imageregistryClient
+	c.clients.Batch = kubeClient.BatchV1beta1()
+
+	for _, ctor := range []func() cache.SharedIndexInformer{
+		func() cache.SharedIndexInformer {
+			informer := kubeInformerFactory.Apps().V1().Deployments()
+			c.listers.Deployments = informer.Lister().Deployments(defaults.ImageRegistryOperatorNamespace)
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := kubeInformerFactory.Core().V1().Services()
+			c.listers.Services = informer.Lister().Services(defaults.ImageRegistryOperatorNamespace)
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := kubeInformerFactory.Core().V1().Secrets()
+			c.listers.Secrets = informer.Lister().Secrets(defaults.ImageRegistryOperatorNamespace)
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := kubeInformerFactory.Core().V1().ConfigMaps()
+			c.listers.ConfigMaps = informer.Lister().ConfigMaps(defaults.ImageRegistryOperatorNamespace)
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := kubeInformerFactory.Core().V1().ServiceAccounts()
+			c.listers.ServiceAccounts = informer.Lister().ServiceAccounts(defaults.ImageRegistryOperatorNamespace)
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := routeInformerFactory.Route().V1().Routes()
+			c.listers.Routes = informer.Lister().Routes(defaults.ImageRegistryOperatorNamespace)
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := kubeInformerFactory.Rbac().V1().ClusterRoles()
+			c.listers.ClusterRoles = informer.Lister()
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := kubeInformerFactory.Rbac().V1().ClusterRoleBindings()
+			c.listers.ClusterRoleBindings = informer.Lister()
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := openshiftConfigKubeInformerFactory.Core().V1().ConfigMaps()
+			c.listers.OpenShiftConfig = informer.Lister().ConfigMaps(defaults.OpenShiftConfigNamespace)
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := configInformerFactory.Config().V1().Proxies()
+			c.listers.ProxyConfigs = informer.Lister()
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := regopInformerFactory.Imageregistry().V1().Configs()
+			c.listers.RegistryConfigs = informer.Lister()
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := kubeSystemKubeInformerFactory.Core().V1().ConfigMaps()
+			c.listers.InstallerConfigMaps = informer.Lister().ConfigMaps(kubeSystemNamespace)
+			return informer.Informer()
+		},
+		func() cache.SharedIndexInformer {
+			informer := configInformerFactory.Config().V1().Infrastructures()
+			c.listers.Infrastructures = informer.Lister()
+			return informer.Informer()
+		},
+	} {
+		informer := ctor()
+		informer.AddEventHandler(c.handler())
+		c.cachesToSync = append(c.cachesToSync, informer.HasSynced)
+	}
+
+	return c
 }
 
 // Controller keeps track of openshift image registry components.
 type Controller struct {
-	kubeconfig *restclient.Config
-	params     parameters.Globals
-	generator  *resource.Generator
-	workqueue  workqueue.RateLimitingInterface
-	listers    *regopclient.Listers
-	clients    *regopclient.Clients
+	kubeconfig   *restclient.Config
+	generator    *resource.Generator
+	workqueue    workqueue.RateLimitingInterface
+	listers      *regopclient.Listers
+	clients      *regopclient.Clients
+	cachesToSync []cache.InformerSynced
 }
 
 func (c *Controller) createOrUpdateResources(cr *imageregistryv1.Config) error {
@@ -159,14 +216,12 @@ func (c *Controller) sync() error {
 	}
 
 	var applyError error
-	removed := false
 	switch cr.Spec.ManagementState {
-	case operatorapi.Removed:
+	case operatorv1.Removed:
 		applyError = c.RemoveResources(cr)
-		removed = true
-	case operatorapi.Managed:
+	case operatorv1.Managed:
 		applyError = c.createOrUpdateResources(cr)
-	case operatorapi.Unmanaged:
+	case operatorv1.Unmanaged:
 		// ignore
 	default:
 		klog.Warningf("unknown custom resource state: %s", cr.Spec.ManagementState)
@@ -181,7 +236,7 @@ func (c *Controller) sync() error {
 		deploy = deploy.DeepCopy() // make sure we won't corrupt the cached vesrion
 	}
 
-	c.syncStatus(cr, deploy, applyError, removed)
+	c.syncStatus(cr, deploy, applyError)
 
 	metadataChanged := strategy.Metadata(&prevCR.ObjectMeta, &cr.ObjectMeta)
 	specChanged := !reflect.DeepEqual(prevCR.Spec, cr.Spec)
@@ -192,7 +247,9 @@ func (c *Controller) sync() error {
 		}
 		klog.Infof("object changed: %s (metadata=%t, spec=%t): %s", utilObjectInfo(cr), metadataChanged, specChanged, difference)
 
-		updatedCR, err := c.clients.RegOp.ImageregistryV1().Configs().Update(cr)
+		updatedCR, err := c.clients.RegOp.ImageregistryV1().Configs().Update(
+			context.TODO(), cr, metaapi.UpdateOptions{},
+		)
 		if err != nil {
 			if !errors.IsConflict(err) {
 				klog.Errorf("unable to update %s: %s", utilObjectInfo(cr), err)
@@ -214,7 +271,9 @@ func (c *Controller) sync() error {
 		}
 		klog.Infof("object changed: %s (status=%t): %s", utilObjectInfo(cr), statusChanged, difference)
 
-		_, err = c.clients.RegOp.ImageregistryV1().Configs().UpdateStatus(cr)
+		_, err = c.clients.RegOp.ImageregistryV1().Configs().UpdateStatus(
+			context.TODO(), cr, metaapi.UpdateOptions{},
+		)
 		if err != nil {
 			if !errors.IsConflict(err) {
 				klog.Errorf("unable to update status %s: %s", utilObjectInfo(cr), err)
@@ -261,11 +320,6 @@ func (c *Controller) eventProcessor() {
 func (c *Controller) handler() cache.ResourceEventHandlerFuncs {
 	return cache.ResourceEventHandlerFuncs{
 		AddFunc: func(o interface{}) {
-			if clusterOperator, ok := o.(*configapiv1.ClusterOperator); ok {
-				if clusterOperator.GetName() != defaults.ImageRegistryClusterOperatorResourceName {
-					return
-				}
-			}
 			obj := o.(metaapi.Object)
 			if obj.GetNamespace() == "kube-system" && obj.GetName() != "cluster-config-v1" {
 				return
@@ -289,11 +343,6 @@ func (c *Controller) handler() cache.ResourceEventHandlerFuncs {
 				// Two different versions of the same resource will always have different RVs.
 				return
 			}
-			if clusterOperator, ok := o.(*configapiv1.ClusterOperator); ok {
-				if clusterOperator.GetName() != defaults.ImageRegistryClusterOperatorResourceName {
-					return
-				}
-			}
 			obj := o.(metaapi.Object)
 			if obj.GetNamespace() == "kube-system" && obj.GetName() != "cluster-config-v1" {
 				return
@@ -316,11 +365,6 @@ func (c *Controller) handler() cache.ResourceEventHandlerFuncs {
 				}
 				klog.V(4).Infof("recovered deleted object %q from tombstone", object.GetName())
 			}
-			if clusterOperator, ok := o.(*configapiv1.ClusterOperator); ok {
-				if clusterOperator.GetName() != defaults.ImageRegistryClusterOperatorResourceName {
-					return
-				}
-			}
 			obj := o.(metaapi.Object)
 			if obj.GetNamespace() == "kube-system" && obj.GetName() != "cluster-config-v1" {
 				return
@@ -332,201 +376,17 @@ func (c *Controller) handler() cache.ResourceEventHandlerFuncs {
 }
 
 // Run starts the Controller.
-func (c *Controller) Run(stopCh <-chan struct{}) error {
+func (c *Controller) Run(stopCh <-chan struct{}) {
+	defer utilruntime.HandleCrash()
 	defer c.workqueue.ShutDown()
 
-	var err error
-
-	c.clients.Core, err = coreset.NewForConfig(c.kubeconfig)
-	if err != nil {
-		return err
-	}
-
-	c.clients.Apps, err = appsset.NewForConfig(c.kubeconfig)
-	if err != nil {
-		return err
-	}
-
-	c.clients.RBAC, err = rbacset.NewForConfig(c.kubeconfig)
-	if err != nil {
-		return err
-	}
-
-	c.clients.Kube, err = kubeset.NewForConfig(c.kubeconfig)
-	if err != nil {
-		return err
-	}
-
-	c.clients.Route, err = routesetv1.NewForConfig(c.kubeconfig)
-	if err != nil {
-		return err
-	}
-
-	c.clients.Config, err = configsetv1.NewForConfig(c.kubeconfig)
-	if err != nil {
-		return err
-	}
-
-	c.clients.RegOp, err = regopset.NewForConfig(c.kubeconfig)
-	if err != nil {
-		return err
-	}
-
-	c.clients.Batch, err = batchset.NewForConfig(c.kubeconfig)
-	if err != nil {
-		return err
-	}
-
-	routeClient, err := routeset.NewForConfig(c.kubeconfig)
-	if err != nil {
-		return err
-	}
-
-	configClient, err := configset.NewForConfig(c.kubeconfig)
-	if err != nil {
-		return err
-	}
-
-	configInformerFactory := configinformers.NewSharedInformerFactory(configClient, defaultResyncDuration)
-	kubeInformerFactory := kubeinformers.NewSharedInformerFactoryWithOptions(c.clients.Kube, defaultResyncDuration, kubeinformers.WithNamespace(c.params.Deployment.Namespace))
-	openshiftConfigKubeInformerFactory := kubeinformers.NewSharedInformerFactoryWithOptions(c.clients.Kube, defaultResyncDuration, kubeinformers.WithNamespace(openshiftConfigNamespace))
-	kubeSystemKubeInformerFactory := kubeinformers.NewSharedInformerFactoryWithOptions(c.clients.Kube, defaultResyncDuration, kubeinformers.WithNamespace(kubeSystemNamespace))
-	regopInformerFactory := regopinformers.NewSharedInformerFactory(c.clients.RegOp, defaultResyncDuration)
-	routeInformerFactory := routeinformers.NewSharedInformerFactoryWithOptions(routeClient, defaultResyncDuration, routeinformers.WithNamespace(c.params.Deployment.Namespace))
-
-	var informers []cache.SharedIndexInformer
-	for _, ctor := range []func() cache.SharedIndexInformer{
-		func() cache.SharedIndexInformer {
-			informer := kubeInformerFactory.Apps().V1().Deployments()
-			c.listers.Deployments = informer.Lister().Deployments(c.params.Deployment.Namespace)
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := kubeInformerFactory.Apps().V1().DaemonSets()
-			c.listers.DaemonSets = informer.Lister().DaemonSets(c.params.Deployment.Namespace)
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := kubeInformerFactory.Core().V1().Services()
-			c.listers.Services = informer.Lister().Services(c.params.Deployment.Namespace)
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := kubeInformerFactory.Core().V1().Secrets()
-			c.listers.Secrets = informer.Lister().Secrets(c.params.Deployment.Namespace)
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := kubeInformerFactory.Core().V1().ConfigMaps()
-			c.listers.ConfigMaps = informer.Lister().ConfigMaps(c.params.Deployment.Namespace)
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := kubeInformerFactory.Core().V1().ServiceAccounts()
-			c.listers.ServiceAccounts = informer.Lister().ServiceAccounts(c.params.Deployment.Namespace)
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := routeInformerFactory.Route().V1().Routes()
-			c.listers.Routes = informer.Lister().Routes(c.params.Deployment.Namespace)
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := kubeInformerFactory.Rbac().V1().ClusterRoles()
-			c.listers.ClusterRoles = informer.Lister()
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := kubeInformerFactory.Rbac().V1().ClusterRoleBindings()
-			c.listers.ClusterRoleBindings = informer.Lister()
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := openshiftConfigKubeInformerFactory.Core().V1().ConfigMaps()
-			c.listers.OpenShiftConfig = informer.Lister().ConfigMaps(openshiftConfigNamespace)
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := kubeSystemKubeInformerFactory.Core().V1().ConfigMaps()
-			c.listers.InstallerConfigMaps = informer.Lister().ConfigMaps(kubeSystemNamespace)
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := configInformerFactory.Config().V1().Images()
-			c.listers.ImageConfigs = informer.Lister()
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := configInformerFactory.Config().V1().ClusterOperators()
-			c.listers.ClusterOperators = informer.Lister()
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := configInformerFactory.Config().V1().Proxies()
-			c.listers.ProxyConfigs = informer.Lister()
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := regopInformerFactory.Imageregistry().V1().Configs()
-			c.listers.RegistryConfigs = informer.Lister()
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := regopInformerFactory.Imageregistry().V1().ImagePruners()
-			c.listers.ImagePrunerConfigs = informer.Lister()
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := configInformerFactory.Config().V1().Infrastructures()
-			c.listers.Infrastructures = informer.Lister()
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := kubeInformerFactory.Batch().V1beta1().CronJobs()
-			c.listers.CronJobs = informer.Lister().CronJobs(defaults.ImageRegistryOperatorNamespace)
-			return informer.Informer()
-		},
-		func() cache.SharedIndexInformer {
-			informer := kubeInformerFactory.Batch().V1().Jobs()
-			c.listers.Jobs = informer.Lister().Jobs(defaults.ImageRegistryOperatorNamespace)
-			return informer.Informer()
-		},
-	} {
-		informer := ctor()
-		informer.AddEventHandler(c.handler())
-		informers = append(informers, informer)
-	}
-
-	clusterOperatorStatusController := NewClusterOperatorStatusController(
-		c.clients.Config,
-		configInformerFactory.Config().V1().ClusterOperators(),
-		regopInformerFactory.Imageregistry().V1().Configs(),
-		kubeInformerFactory.Apps().V1().Deployments(),
-		c.kubeconfig, c.clients, c.listers,
-	)
-
-	configInformerFactory.Start(stopCh)
-	kubeInformerFactory.Start(stopCh)
-	openshiftConfigKubeInformerFactory.Start(stopCh)
-	kubeSystemKubeInformerFactory.Start(stopCh)
-	regopInformerFactory.Start(stopCh)
-	routeInformerFactory.Start(stopCh)
-
-	// TODO(dmage):This controller should be started from main.
-	go clusterOperatorStatusController.Run(stopCh)
-
-	klog.Info("waiting for informer caches to sync")
-	for _, informer := range informers {
-		if ok := cache.WaitForCacheSync(stopCh, informer.HasSynced); !ok {
-			return fmt.Errorf("failed to wait for caches to sync")
-		}
+	if !cache.WaitForCacheSync(stopCh, c.cachesToSync...) {
+		return
 	}
 
+	klog.Infof("Starting Controller")
 	go wait.Until(c.eventProcessor, time.Second, stopCh)
 
-	klog.Info("started events processor")
 	<-stopCh
-	klog.Info("shutting down events processor")
-
-	return nil
+	klog.Infof("Shutting down Controller ...")
 }
