@@ -1,30 +1,33 @@
 package e2e
 
 import (
+	"context"
 	"fmt"
 	"reflect"
 	"testing"
 	"time"
 
-	"github.com/openshift/cluster-image-registry-operator/defaults"
-	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
-	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
-	storages3 "github.com/openshift/cluster-image-registry-operator/pkg/storage/s3"
-	"github.com/openshift/cluster-image-registry-operator/pkg/storage/util"
-	"github.com/openshift/cluster-image-registry-operator/test/framework"
-	"github.com/openshift/cluster-image-registry-operator/test/framework/mock/listers"
-
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/awserr"
 	"github.com/aws/aws-sdk-go/aws/credentials"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/s3"
-	configapiv1 "github.com/openshift/api/config/v1"
-	operatorapi "github.com/openshift/api/operator/v1"
+
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/wait"
+
+	configapiv1 "github.com/openshift/api/config/v1"
+	operatorapi "github.com/openshift/api/operator/v1"
+
+	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/defaults"
+	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
+	storages3 "github.com/openshift/cluster-image-registry-operator/pkg/storage/s3"
+	"github.com/openshift/cluster-image-registry-operator/pkg/storage/util"
+	"github.com/openshift/cluster-image-registry-operator/test/framework"
+	"github.com/openshift/cluster-image-registry-operator/test/framework/mock/listers"
 )
 
 var (
@@ -36,13 +39,23 @@ var (
 )
 
 func TestAWSDefaults(t *testing.T) {
+	te := framework.Setup(t)
+	defer framework.TeardownImageRegistry(te)
+
 	kcfg, err := regopclient.GetConfig()
 	if err != nil {
 		t.Fatalf("Error building kubeconfig: %s", err)
 	}
 
 	newMockLister, err := listers.NewMockLister(kcfg)
+	if err != nil {
+		t.Fatalf("unable to create mock lister: %v", err)
+	}
+
 	mockLister, err := newMockLister.GetListers()
+	if err != nil {
+		t.Fatalf("unable to get listers from mock lister: %v", err)
+	}
 
 	infra, err := util.GetInfrastructure(mockLister)
 	if err != nil {
@@ -53,17 +66,14 @@ func TestAWSDefaults(t *testing.T) {
 		t.Skip("skipping on non-AWS platform")
 	}
 
-	client := framework.MustNewClientset(t, nil)
-
 	// TODO: Move these checks to a conformance test run on all providers
-	defer framework.MustRemoveImageRegistry(t, client)
-	framework.MustDeployImageRegistry(t, client, nil)
-	framework.MustEnsureImageRegistryIsAvailable(t, client)
-	framework.MustEnsureInternalRegistryHostnameIsSet(t, client)
-	framework.MustEnsureClusterOperatorStatusIsNormal(t, client)
-	framework.MustEnsureOperatorIsNotHotLooping(t, client)
-	framework.MustEnsureServiceCAConfigMap(t, client)
-	framework.MustEnsureNodeCADaemonSetIsAvailable(t, client)
+	framework.DeployImageRegistry(te, nil)
+	framework.WaitUntilImageRegistryIsAvailable(te)
+	framework.EnsureInternalRegistryHostnameIsSet(te)
+	framework.EnsureClusterOperatorStatusIsNormal(te)
+	framework.EnsureOperatorIsNotHotLooping(te)
+	framework.EnsureServiceCAConfigMap(te)
+	framework.EnsureNodeCADaemonSetIsAvailable(te)
 
 	cfg, err := storages3.GetConfig(mockLister)
 	if err != nil {
@@ -72,19 +82,23 @@ func TestAWSDefaults(t *testing.T) {
 
 	// Check that the image-registry-private-configuration secret exists and
 	// contains the correct information
-	imageRegistryPrivateConfiguration, err := client.Secrets(defaults.ImageRegistryOperatorNamespace).Get(defaults.ImageRegistryPrivateConfiguration, metav1.GetOptions{})
+	imageRegistryPrivateConfiguration, err := te.Client().Secrets(defaults.ImageRegistryOperatorNamespace).Get(
+		context.Background(), defaults.ImageRegistryPrivateConfiguration, metav1.GetOptions{},
+	)
 	if err != nil {
 		t.Errorf("unable to get secret %s/%s: %#v", defaults.ImageRegistryOperatorNamespace, defaults.ImageRegistryPrivateConfiguration, err)
 	}
-	accessKey, _ := imageRegistryPrivateConfiguration.Data["REGISTRY_STORAGE_S3_ACCESSKEY"]
-	secretKey, _ := imageRegistryPrivateConfiguration.Data["REGISTRY_STORAGE_S3_SECRETKEY"]
+	accessKey := imageRegistryPrivateConfiguration.Data["REGISTRY_STORAGE_S3_ACCESSKEY"]
+	secretKey := imageRegistryPrivateConfiguration.Data["REGISTRY_STORAGE_S3_SECRETKEY"]
 	if string(accessKey) != cfg.AccessKey || string(secretKey) != cfg.SecretKey {
 		t.Errorf("secret %s/%s contains incorrect aws credentials (AccessKey or SecretKey)", defaults.ImageRegistryOperatorNamespace, defaults.ImageRegistryPrivateConfiguration)
 	}
 
 	// Check that the image registry resource exists
 	// and contains the correct region and a non-empty bucket name
-	cr, err := client.Configs().Get(defaults.ImageRegistryResourceName, metav1.GetOptions{})
+	cr, err := te.Client().Configs().Get(
+		context.Background(), defaults.ImageRegistryResourceName, metav1.GetOptions{},
+	)
 	if err != nil {
 		t.Errorf("unable to get custom resource %s/%s: %#v", defaults.ImageRegistryOperatorNamespace, defaults.ImageRegistryResourceName, err)
 	}
@@ -104,45 +118,12 @@ func TestAWSDefaults(t *testing.T) {
 		}
 	}
 
-	// Wait for the image registry resource to have an updated StorageExists condition
-	errs := framework.ConditionExistsWithStatusAndReason(client, defaults.StorageExists, operatorapi.ConditionTrue, "S3 Bucket Exists")
-	if len(errs) != 0 {
-		for _, err := range errs {
-			t.Errorf("%#v", err)
-		}
-	}
-
-	// Wait for the image registry resource to have an updated StorageTagged condition
-	errs = framework.ConditionExistsWithStatusAndReason(client, defaults.StorageTagged, operatorapi.ConditionTrue, "Tagging Successful")
-	if len(errs) != 0 {
-		for _, err := range errs {
-			t.Errorf("%#v", err)
-		}
-	}
-
-	// Wait for the image registry resource to have an updated StorageEncrypted condition
-	errs = framework.ConditionExistsWithStatusAndReason(client, defaults.StorageEncrypted, operatorapi.ConditionTrue, "Encryption Successful")
-	if len(errs) != 0 {
-		for _, err := range errs {
-			t.Errorf("%#v", err)
-		}
-	}
-
-	// Wait for the image registry resource to have an updated StorageIncompleteUploadCleanupEnabled condition
-	errs = framework.ConditionExistsWithStatusAndReason(client, defaults.StorageIncompleteUploadCleanupEnabled, operatorapi.ConditionTrue, "Enable Cleanup Successful")
-	if len(errs) != 0 {
-		for _, err := range errs {
-			t.Errorf("%#v", err)
-		}
-	}
-
-	// Wait for the image registry resource to have an updated StoragePublicAccessBlocked condition
-	errs = framework.ConditionExistsWithStatusAndReason(client, defaults.StoragePublicAccessBlocked, operatorapi.ConditionTrue, "Public Access Block Successful")
-	if len(errs) != 0 {
-		for _, err := range errs {
-			t.Errorf("%#v", err)
-		}
-	}
+	// Wait for the image registry resource to have an updated  conditions
+	framework.ConditionExistsWithStatusAndReason(te, defaults.StorageExists, operatorapi.ConditionTrue, "S3 Bucket Exists")
+	framework.ConditionExistsWithStatusAndReason(te, defaults.StorageTagged, operatorapi.ConditionTrue, "Tagging Successful")
+	framework.ConditionExistsWithStatusAndReason(te, defaults.StorageEncrypted, operatorapi.ConditionTrue, "Encryption Successful")
+	framework.ConditionExistsWithStatusAndReason(te, defaults.StorageIncompleteUploadCleanupEnabled, operatorapi.ConditionTrue, "Enable Cleanup Successful")
+	framework.ConditionExistsWithStatusAndReason(te, defaults.StoragePublicAccessBlocked, operatorapi.ConditionTrue, "Public Access Block Successful")
 
 	// Check that the S3 bucket that we created exists and is accessible
 	sess, err := session.NewSession(&aws.Config{
@@ -222,7 +203,6 @@ func TestAWSDefaults(t *testing.T) {
 		if aerr, ok := err.(awserr.Error); ok {
 			t.Errorf("unable to get encryption information for S3 bucket: %#v, %#v", aerr.Code(), aerr.Error())
 		} else {
-
 			t.Errorf("unknown error occurred getting encryption information for S3 bucket: %#v", err)
 		}
 	}
@@ -239,7 +219,6 @@ func TestAWSDefaults(t *testing.T) {
 
 	for _, wantedEncryptionRule := range wantedBucketEncryption.Rules {
 		found := false
-
 		for _, gotRule := range getBucketEncryptionResult.ServerSideEncryptionConfiguration.Rules {
 			if reflect.DeepEqual(wantedEncryptionRule, gotRule) {
 				found = true
@@ -259,7 +238,6 @@ func TestAWSDefaults(t *testing.T) {
 		if aerr, ok := err.(awserr.Error); ok {
 			t.Errorf("unable to get lifecycle information for S3 bucket: %#v, %#v", aerr.Code(), aerr.Error())
 		} else {
-
 			t.Errorf("unknown error occurred getting lifecycle information for S3 bucket: %#v", err)
 		}
 	}
@@ -279,7 +257,6 @@ func TestAWSDefaults(t *testing.T) {
 	}
 	for _, wantedRule := range wantedLifecycleConfiguration.Rules {
 		found := false
-
 		for _, gotRule := range getBucketLifecycleConfigurationResult.Rules {
 			if reflect.DeepEqual(wantedRule, gotRule) {
 				found = true
@@ -291,7 +268,9 @@ func TestAWSDefaults(t *testing.T) {
 		}
 	}
 
-	registryDeployment, err := client.Deployments(defaults.ImageRegistryOperatorNamespace).Get(defaults.ImageRegistryName, metav1.GetOptions{})
+	registryDeployment, err := te.Client().Deployments(defaults.ImageRegistryOperatorNamespace).Get(
+		context.Background(), defaults.ImageRegistryName, metav1.GetOptions{},
+	)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -336,13 +315,23 @@ func TestAWSDefaults(t *testing.T) {
 }
 
 func TestAWSUnableToCreateBucketOnStartup(t *testing.T) {
+	te := framework.Setup(t)
+	defer framework.TeardownImageRegistry(te)
+
 	kubeconfig, err := regopclient.GetConfig()
 	if err != nil {
 		t.Fatalf("unable to get kubeconfig: %s", err)
 	}
 
 	newMockLister, err := listers.NewMockLister(kubeconfig)
+	if err != nil {
+		t.Fatalf("unable to create mock lister: %v", err)
+	}
+
 	mockLister, err := newMockLister.GetListers()
+	if err != nil {
+		t.Fatalf("unable to get listers from mock lister: %v", err)
+	}
 
 	infra, err := util.GetInfrastructure(mockLister)
 	if err != nil {
@@ -353,51 +342,50 @@ func TestAWSUnableToCreateBucketOnStartup(t *testing.T) {
 		t.Skip("skipping on non-AWS platform")
 	}
 
-	client := framework.MustNewClientset(t, nil)
-
 	// Create the image-registry-private-configuration-user secret using the invalid credentials
 	if _, err := framework.CreateOrUpdateSecret(defaults.ImageRegistryPrivateConfigurationUser, defaults.ImageRegistryOperatorNamespace, fakeAWSCredsData); err != nil {
 		t.Fatalf("unable to create secret %q: %#v", fmt.Sprintf("%s/%s", defaults.ImageRegistryOperatorNamespace, defaults.ImageRegistryPrivateConfigurationUser), err)
 	}
 
-	defer framework.MustRemoveImageRegistry(t, client)
-	framework.MustDeployImageRegistry(t, client, nil)
+	framework.DeployImageRegistry(te, nil)
 
 	// Wait for the image registry resource to have an updated StorageExists condition
-	errs := framework.ConditionExistsWithStatusAndReason(client, defaults.StorageExists, operatorapi.ConditionFalse, "InvalidAccessKeyId")
-	if len(errs) != 0 {
-		for _, err := range errs {
-			t.Errorf("%#v", err)
-		}
-	}
+	framework.ConditionExistsWithStatusAndReason(te, defaults.StorageExists, operatorapi.ConditionFalse, "InvalidAccessKeyId")
 
 	// Remove the image-registry-private-configuration-user secret
-	err = client.Secrets(defaults.ImageRegistryOperatorNamespace).Delete(defaults.ImageRegistryPrivateConfigurationUser, &metav1.DeleteOptions{})
+	err = te.Client().Secrets(defaults.ImageRegistryOperatorNamespace).Delete(
+		context.Background(), defaults.ImageRegistryPrivateConfigurationUser, metav1.DeleteOptions{},
+	)
 	if err != nil {
 		t.Errorf("unable to remove %s/%s: %#v", defaults.ImageRegistryOperatorNamespace, defaults.ImageRegistryPrivateConfigurationUser, err)
 	}
 
 	// Wait for the image registry resource to have an updated StorageExists condition
-	errs = framework.ConditionExistsWithStatusAndReason(client, defaults.StorageExists, operatorapi.ConditionTrue, "S3 Bucket Exists")
-	if len(errs) != 0 {
-		for _, err := range errs {
-			t.Errorf("%#v", err)
-		}
-	}
+	framework.ConditionExistsWithStatusAndReason(te, defaults.StorageExists, operatorapi.ConditionTrue, "S3 Bucket Exists")
 
-	framework.MustEnsureImageRegistryIsAvailable(t, client)
-	framework.MustEnsureInternalRegistryHostnameIsSet(t, client)
-	framework.MustEnsureClusterOperatorStatusIsNormal(t, client)
+	framework.WaitUntilImageRegistryIsAvailable(te)
+	framework.EnsureInternalRegistryHostnameIsSet(te)
+	framework.EnsureClusterOperatorStatusIsNormal(te)
 }
 
 func TestAWSUpdateCredentials(t *testing.T) {
+	te := framework.Setup(t)
+	defer framework.TeardownImageRegistry(te)
+
 	kcfg, err := regopclient.GetConfig()
 	if err != nil {
 		t.Fatalf("Error building kubeconfig: %s", err)
 	}
 
 	newMockLister, err := listers.NewMockLister(kcfg)
+	if err != nil {
+		t.Fatalf("unable to create mock lister: %v", err)
+	}
+
 	mockLister, err := newMockLister.GetListers()
+	if err != nil {
+		t.Fatalf("unable to get listers from mock lister: %v", err)
+	}
 
 	infra, err := util.GetInfrastructure(mockLister)
 	if err != nil {
@@ -408,13 +396,10 @@ func TestAWSUpdateCredentials(t *testing.T) {
 		t.Skip("skipping on non-AWS platform")
 	}
 
-	client := framework.MustNewClientset(t, nil)
-
-	defer framework.MustRemoveImageRegistry(t, client)
-	framework.MustDeployImageRegistry(t, client, nil)
-	framework.MustEnsureImageRegistryIsAvailable(t, client)
-	framework.MustEnsureInternalRegistryHostnameIsSet(t, client)
-	framework.MustEnsureClusterOperatorStatusIsNormal(t, client)
+	framework.DeployImageRegistry(te, nil)
+	framework.WaitUntilImageRegistryIsAvailable(te)
+	framework.EnsureInternalRegistryHostnameIsSet(te)
+	framework.EnsureClusterOperatorStatusIsNormal(te)
 
 	// Create the image-registry-private-configuration-user secret using the invalid credentials
 	err = wait.PollImmediate(1*time.Second, framework.AsyncOperationTimeout, func() (stop bool, err error) {
@@ -438,40 +423,42 @@ func TestAWSUpdateCredentials(t *testing.T) {
 	}
 
 	// Wait for the image registry resource to have an updated StorageExists condition
-	errs := framework.ConditionExistsWithStatusAndReason(client, defaults.StorageExists, operatorapi.ConditionFalse, "InvalidAccessKeyId")
-	if len(errs) != 0 {
-		for _, err := range errs {
-			t.Errorf("%#v", err)
-		}
-	}
+	framework.ConditionExistsWithStatusAndReason(te, defaults.StorageExists, operatorapi.ConditionFalse, "InvalidAccessKeyId")
 
 	// Remove the image-registry-private-configuration-user secret
-	err = client.Secrets(defaults.ImageRegistryOperatorNamespace).Delete(defaults.ImageRegistryPrivateConfigurationUser, &metav1.DeleteOptions{})
+	err = te.Client().Secrets(defaults.ImageRegistryOperatorNamespace).Delete(
+		context.Background(), defaults.ImageRegistryPrivateConfigurationUser, metav1.DeleteOptions{},
+	)
 	if err != nil {
 		t.Errorf("unable to remove %s/%s: %#v", defaults.ImageRegistryOperatorNamespace, defaults.ImageRegistryPrivateConfigurationUser, err)
 	}
 
 	// Wait for the image registry resource to have an updated StorageExists condition
-	errs = framework.ConditionExistsWithStatusAndReason(client, defaults.StorageExists, operatorapi.ConditionTrue, "S3 Bucket Exists")
-	if len(errs) != 0 {
-		for _, err := range errs {
-			t.Errorf("%#v", err)
-		}
-	}
+	framework.ConditionExistsWithStatusAndReason(te, defaults.StorageExists, operatorapi.ConditionTrue, "S3 Bucket Exists")
 
-	framework.MustEnsureImageRegistryIsAvailable(t, client)
-	framework.MustEnsureInternalRegistryHostnameIsSet(t, client)
-	framework.MustEnsureClusterOperatorStatusIsNormal(t, client)
+	framework.WaitUntilImageRegistryIsAvailable(te)
+	framework.EnsureInternalRegistryHostnameIsSet(te)
+	framework.EnsureClusterOperatorStatusIsNormal(te)
 }
 
 func TestAWSChangeS3Encryption(t *testing.T) {
+	te := framework.Setup(t)
+	defer framework.TeardownImageRegistry(te)
+
 	kubeconfig, err := regopclient.GetConfig()
 	if err != nil {
 		t.Fatalf("unable to get kubeconfig: %s", err)
 	}
 
 	newMockLister, err := listers.NewMockLister(kubeconfig)
+	if err != nil {
+		t.Fatalf("unable to create mock lister: %v", err)
+	}
+
 	mockLister, err := newMockLister.GetListers()
+	if err != nil {
+		t.Fatalf("unable to get listers from mock lister: %v", err)
+	}
 
 	infra, err := util.GetInfrastructure(mockLister)
 	if err != nil {
@@ -482,27 +469,28 @@ func TestAWSChangeS3Encryption(t *testing.T) {
 		t.Skip("skipping on non-AWS platform")
 	}
 
-	client := framework.MustNewClientset(t, nil)
+	framework.DeployImageRegistry(te, nil)
+	framework.WaitUntilImageRegistryIsAvailable(te)
+	framework.EnsureInternalRegistryHostnameIsSet(te)
+	framework.EnsureClusterOperatorStatusIsNormal(te)
 
-	defer framework.MustRemoveImageRegistry(t, client)
-	framework.MustDeployImageRegistry(t, client, nil)
-	framework.MustEnsureImageRegistryIsAvailable(t, client)
-	framework.MustEnsureInternalRegistryHostnameIsSet(t, client)
-	framework.MustEnsureClusterOperatorStatusIsNormal(t, client)
-
-	cr, err := client.Configs().Get(defaults.ImageRegistryResourceName, metav1.GetOptions{})
+	cr, err := te.Client().Configs().Get(
+		context.Background(), defaults.ImageRegistryResourceName, metav1.GetOptions{},
+	)
 	if err != nil {
 		t.Errorf("unable to get custom resource %s/%s: %#v", defaults.ImageRegistryOperatorNamespace, defaults.ImageRegistryResourceName, err)
 	}
 
 	// Check that the image-registry-private-configuration secret exists and
 	// contains the correct information
-	imageRegistryPrivateConfiguration, err := client.Secrets(defaults.ImageRegistryOperatorNamespace).Get(defaults.ImageRegistryPrivateConfiguration, metav1.GetOptions{})
+	imageRegistryPrivateConfiguration, err := te.Client().Secrets(defaults.ImageRegistryOperatorNamespace).Get(
+		context.Background(), defaults.ImageRegistryPrivateConfiguration, metav1.GetOptions{},
+	)
 	if err != nil {
 		t.Errorf("unable to get secret %s/%s: %#v", defaults.ImageRegistryOperatorNamespace, defaults.ImageRegistryPrivateConfiguration, err)
 	}
-	accessKey, _ := imageRegistryPrivateConfiguration.Data["REGISTRY_STORAGE_S3_ACCESSKEY"]
-	secretKey, _ := imageRegistryPrivateConfiguration.Data["REGISTRY_STORAGE_S3_SECRETKEY"]
+	accessKey := imageRegistryPrivateConfiguration.Data["REGISTRY_STORAGE_S3_ACCESSKEY"]
+	secretKey := imageRegistryPrivateConfiguration.Data["REGISTRY_STORAGE_S3_SECRETKEY"]
 
 	// Check that the S3 bucket that we created exists and is accessible
 	sess, err := session.NewSession(&aws.Config{
@@ -558,7 +546,13 @@ func TestAWSChangeS3Encryption(t *testing.T) {
 		}
 	}
 
-	if _, err = client.Configs().Patch(defaults.ImageRegistryResourceName, types.MergePatchType, []byte(`{"spec": {"storage": {"s3": {"keyID": "testKey"}}}}`)); err != nil {
+	if _, err = te.Client().Configs().Patch(
+		context.Background(),
+		defaults.ImageRegistryResourceName,
+		types.MergePatchType,
+		[]byte(`{"spec": {"storage": {"s3": {"keyID": "testKey"}}}}`),
+		metav1.PatchOptions{},
+	); err != nil {
 		t.Errorf("unable to patch image registry custom resource: %#v", err)
 	}
 
@@ -606,7 +600,9 @@ func TestAWSChangeS3Encryption(t *testing.T) {
 		t.Errorf("s3 encryption rule was either not found or was not correct: wanted \"%#v\": looked in %#v", wantedBucketEncryption, getBucketEncryptionResult)
 	}
 
-	registryDeployment, err := client.Deployments(defaults.ImageRegistryOperatorNamespace).Get(defaults.ImageRegistryName, metav1.GetOptions{})
+	registryDeployment, err := te.Client().Deployments(defaults.ImageRegistryOperatorNamespace).Get(
+		context.Background(), defaults.ImageRegistryName, metav1.GetOptions{},
+	)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -652,13 +648,23 @@ func TestAWSChangeS3Encryption(t *testing.T) {
 }
 
 func TestAWSFinalizerDeleteS3Bucket(t *testing.T) {
+	te := framework.Setup(t)
+	defer framework.TeardownImageRegistry(te)
+
 	kcfg, err := regopclient.GetConfig()
 	if err != nil {
 		t.Fatalf("Error building kubeconfig: %s", err)
 	}
 
 	newMockLister, err := listers.NewMockLister(kcfg)
+	if err != nil {
+		t.Fatalf("unable to create mock lister: %v", err)
+	}
+
 	mockLister, err := newMockLister.GetListers()
+	if err != nil {
+		t.Fatalf("unable to get listers from mock lister: %v", err)
+	}
 
 	infra, err := util.GetInfrastructure(mockLister)
 	if err != nil {
@@ -669,20 +675,21 @@ func TestAWSFinalizerDeleteS3Bucket(t *testing.T) {
 		t.Skip("skipping on non-AWS platform")
 	}
 
-	client := framework.MustNewClientset(t, nil)
+	framework.DeployImageRegistry(te, nil)
+	framework.WaitUntilImageRegistryIsAvailable(te)
+	framework.EnsureInternalRegistryHostnameIsSet(te)
+	framework.EnsureClusterOperatorStatusIsNormal(te)
 
-	defer framework.MustRemoveImageRegistry(t, client)
-	framework.MustDeployImageRegistry(t, client, nil)
-	framework.MustEnsureImageRegistryIsAvailable(t, client)
-	framework.MustEnsureInternalRegistryHostnameIsSet(t, client)
-	framework.MustEnsureClusterOperatorStatusIsNormal(t, client)
-
-	cr, err := client.Configs().Get(defaults.ImageRegistryResourceName, metav1.GetOptions{})
+	cr, err := te.Client().Configs().Get(
+		context.Background(), defaults.ImageRegistryResourceName, metav1.GetOptions{},
+	)
 	if err != nil {
 		t.Errorf("unable to get custom resource %s/%s: %#v", defaults.ImageRegistryOperatorNamespace, defaults.ImageRegistryResourceName, err)
 	}
 	// Check that the S3 bucket gets cleaned up by the finalizer (if we manage it)
-	err = client.Configs().Delete(defaults.ImageRegistryResourceName, &metav1.DeleteOptions{})
+	err = te.Client().Configs().Delete(
+		context.Background(), defaults.ImageRegistryResourceName, metav1.DeleteOptions{},
+	)
 	if err != nil {
 		t.Errorf("unable to get image registry resource: %#v", err)
 	}
@@ -712,5 +719,4 @@ func TestAWSFinalizerDeleteS3Bucket(t *testing.T) {
 	if exists {
 		t.Errorf("s3 bucket should have been deleted, but it wasn't")
 	}
-
 }
